#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-2TEwVOwKbjs98186y68TwV
key:                  string-interpolate-0.3.4.0-2TEwVOwKbjs98186y68TwV
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  9bb48447e3d0d1a82b005f3a8fd20699
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-2TEwVOwKbjs98186y68TwV
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    haskell-src-exts-1.23.1-3JlEDY0GlvbDl9TOFDgSoA
    haskell-src-meta-0.8.15-kV5jtapNpO7GyNxJr9TNR
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl template-haskell-2.20.0.0
    text-2.0.2 text-conversions-0.3.1.1-JsLcY6ADZIc9Ezwg94VfhN
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

